==> kitemmodels-5.36.0.tar.xz: kitemmodels-5.36.0/tests/proxymodeltestapp/statesaverwidget.h <==
/*
    Copyright (C) 2010 Klarälvdalens Datakonsult AB,
        a KDAB Group company, info@kdab.net,
        author Stephen Kelly <stephen@kdab.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef STATESAVERWIDGET_H
#define STATESAVERWIDGET_H

#include <QWidget>

#include "kviewstatesaver.h"

class QTreeView;

class DynamicTreeWidget;

class DynamicTreeStateSaver : public KViewStateSaver
{
    Q_OBJECT
public:
    DynamicTreeStateSaver(QObject *parent = 0);

protected:
    /* reimp */ QModelIndex indexFromConfigString(const QAbstractItemModel *model, const QString &key) const;
    /* reimp */ QString indexToConfigString(const QModelIndex &index) const;
};

class StateSaverWidget : public QWidget
{
    Q_OBJECT
public:
    StateSaverWidget(QWidget *parent = 0, Qt::WindowFlags f = Qt::WindowFlags());
    ~StateSaverWidget();

private Q_SLOTS:
    void saveState();
    void restoreState();

private:
    DynamicTreeWidget *m_dynamicTreeWidget;
    QTreeView *m_view;
};

#endif

==> kitemmodels-5.40.0.tar.xz: kitemmodels-5.40.0/tests/proxymodeltestapp/statesaverwidget.h <==
/*
    Copyright (C) 2010 Klarälvdalens Datakonsult AB,
        a KDAB Group company, info@kdab.net,
        author Stephen Kelly <stephen@kdab.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef STATESAVERWIDGET_H
#define STATESAVERWIDGET_H

#include <QWidget>

#include "kviewstatesaver.h"

class QTreeView;

class DynamicTreeWidget;

class DynamicTreeStateSaver : public KViewStateSaver
{
    Q_OBJECT
public:
    DynamicTreeStateSaver(QObject *parent = nullptr);

protected:
    /* reimp */ QModelIndex indexFromConfigString(const QAbstractItemModel *model, const QString &key) const;
    /* reimp */ QString indexToConfigString(const QModelIndex &index) const;
};

class StateSaverWidget : public QWidget
{
    Q_OBJECT
public:
    StateSaverWidget(QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
    ~StateSaverWidget();

private Q_SLOTS:
    void saveState();
    void restoreState();

private:
    DynamicTreeWidget *m_dynamicTreeWidget;
    QTreeView *m_view;
};

#endif
